searchData={"items":[{"type":"module","title":"Ollama","doc":"![Ollama-ex](https://raw.githubusercontent.com/lebrunel/ollama-ex/main/media/poster.webp)\n\n![License](https://img.shields.io/github/license/lebrunel/ollama-ex?color=informational)\n\n[Ollama](https://ollama.ai) is a nifty little tool for running large language\nmodels locally, and this is a nifty little library for working with Ollama in\nElixir.\n\n- 🦙 API client fully implementing the Ollama API\n- 🛜 Streaming API requests\n  - Stream to an Enumerable\n  - Or stream messages to any Elixir process","ref":"Ollama.html"},{"type":"module","title":"Installation - Ollama","doc":"The package can be installed by adding `ollama` to your list of dependencies\nin `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:ollama, \"0.5.2\"}\n  ]\nend\n```","ref":"Ollama.html#module-installation"},{"type":"module","title":"Quickstart - Ollama","doc":"> ##","ref":"Ollama.html#module-quickstart"},{"type":"module","title":"API change {: .info} - Ollama","doc":">\n> The last two minor versions have introduced breaking API changes. We're\nclose to an API that feels nice, so hopefully no more breaking changes 🙏🏻.\n>\n> - `0.5.0` - Streaming requests continues to return a `t:Task.t/0` when the\n`:stream` option is a `t:pid/0`, but now returns an `t:Enumerable.t/0` when\n`:stream` is `true`. Refer to the [section on Streaming](#module-streaming).\n> - `0.4.0` - The `Ollama.API` module has been deprecated in favour of the top\nlevel `Ollama` module. `Ollama.API` will be removed in version 1.\n\nAssuming you have Ollama running on localhost, and that you have installed a\nmodel, use `completion/2` or `chat/2` interact with the model.\n\n#","ref":"Ollama.html#module-api-change-info"},{"type":"module","title":"1. Generate a completion - Ollama","doc":"```elixir\niex> client = Ollama.init()\n\niex> Ollama.completion(client, [\n...>   model: \"llama2\",\n...>   prompt: \"Why is the sky blue?\",\n...> ])\n{:ok, %{\"response\" => \"The sky is blue because it is the color of the sky.\", ...}}\n```\n\n#","ref":"Ollama.html#module-1-generate-a-completion"},{"type":"module","title":"2. Generate the next message in a chat - Ollama","doc":"```elixir\niex> client = Ollama.init()\niex> messages = [\n...>   %{role: \"system\", content: \"You are a helpful assistant.\"},\n...>   %{role: \"user\", content: \"Why is the sky blue?\"},\n...>   %{role: \"assistant\", content: \"Due to rayleigh scattering.\"},\n...>   %{role: \"user\", content: \"How is that different than mie scattering?\"},\n...> ]\n\niex> Ollama.chat(client, [\n...>   model: \"llama2\",\n...>   messages: messages,\n...> ])\n{:ok, %{\"message\" => %{\n  \"role\" => \"assistant\",\n  \"content\" => \"Mie scattering affects all wavelengths similarly, while Rayleigh favors shorter ones.\"\n}, ...}}\n```","ref":"Ollama.html#module-2-generate-the-next-message-in-a-chat"},{"type":"module","title":"Streaming - Ollama","doc":"On endpoints where streaming is supported, a streaming request can be initiated\nby setting the `:stream` option to `true` or a `t:pid/0`.\n\nWhen `:stream` is `true` a lazy `t:Enumerable.t/0` is returned which can be\nused with any `Stream` functions.\n\n```elixir\niex> Ollama.completion(client, [\n...>   model: \"llama2\",\n...>   prompt: \"Why is the sky blue?\",\n...>   stream: true,\n...> ])\n{:ok, stream}\n\niex> is_function(stream, 2)\ntrue\n\niex> stream\n...> |> Stream.each(& Process.send(pid, &1, [])\n...> |> Stream.run()\n:ok\n```\n\nBecause the above approach builds the `t:Enumerable.t/0` by calling `receive`,\nusing this approach inside `GenServer` callbacks may cause the GenServer to\nmisbehave. Instead of setting the `:stream` option to `true`, you can set it\nto a `t:pid/0`. A `t:Task.t/0` is returned which will send messages to the\nspecified process.\n\nThe example below demonstrates making a streaming request in a LiveView event,\nand sends each of the streaming messages back to the same LiveView process.\n\n```elixir\ndefmodule MyApp.ChatLive do\n  use Phoenix.LiveView\n\n  # When the client invokes the \"prompt\" event, create a streaming request and\n  # asynchronously send messages back to self.\n  def handle_event(\"prompt\", %{\"message\" => prompt}, socket) do\n    {:ok, task} = Ollama.completion(Ollama.init(), [\n      model: \"llama2\",\n      prompt: prompt,\n      stream: self(),\n    ])\n\n    {:noreply, assign(socket, current_request: task)}\n  end\n\n  # The streaming request sends messages back to the LiveView process.\n  def handle_info({_request_pid, {:data, _data}} = message, socket) do\n    pid = socket.assigns.current_request.pid\n    case message do\n      {^pid, {:data, %{\"done\" => false} = data}} ->\n        # handle each streaming chunk\n\n      {^pid, {:data, %{\"done\" => true} = data}} ->\n        # handle the final streaming chunk\n\n      {_pid, _data} ->\n        # this message was not expected!\n    end\n  end\n\n  # Tidy up when the request is finished\n  def handle_info({ref, {:ok, %Req.Response{status: 200}}}, socket) do\n    Process.demonitor(ref, [:flush])\n    {:noreply, assign(socket, current_request: nil)}\n  end\nend\n```\n\nRegardless of which approach to streaming you use, each of the streaming\nmessages are a plain `t:map/0`. Refer to the [Ollama API docs](https://github.com/ollama/ollama/blob/main/docs/api.md)\nfor the schema.","ref":"Ollama.html#module-streaming"},{"type":"function","title":"Ollama.chat/2","doc":"Generates the next message in a chat using the specified model. Optionally\nstreamable.","ref":"Ollama.html#chat/2"},{"type":"function","title":"Options - Ollama.chat/2","doc":"* `:model` (`t:String.t/0`) - Required. The ollama model name.\n* `:messages` (list of `t:map/0`) - Required. List of messages - used to keep a chat memory.\n* `:template` (`t:String.t/0`) - Prompt template, overriding the model default.\n* `:format` (`t:String.t/0`) - Set the expected format of the response (`json`).\n* `:stream` - See [section on streaming](#module-streaming). The default value is `false`.\n* `:keep_alive` - How long to keep the model loaded.\n* `:options` - Additional advanced [model parameters](https://github.com/jmorganca/ollama/blob/main/docs/modelfile.md#valid-parameters-and-values).","ref":"Ollama.html#chat/2-options"},{"type":"function","title":"Message structure - Ollama.chat/2","doc":"Each message is a map with the following fields:\n\n* `:role` (`t:String.t/0`) - Required. The role of the message, either `system`, `user` or `assistant`.\n* `:content` (`t:String.t/0`) - Required. The content of the message.\n* `:images` (list of `t:String.t/0`) - *(optional)* List of Base64 encoded images (for multimodal models only).","ref":"Ollama.html#chat/2-message-structure"},{"type":"function","title":"Examples - Ollama.chat/2","doc":"iex> messages = [\n    ...>   %{role: \"system\", content: \"You are a helpful assistant.\"},\n    ...>   %{role: \"user\", content: \"Why is the sky blue?\"},\n    ...>   %{role: \"assistant\", content: \"Due to rayleigh scattering.\"},\n    ...>   %{role: \"user\", content: \"How is that different than mie scattering?\"},\n    ...> ]\n\n    iex> Ollama.chat(client, [\n    ...>   model: \"llama2\",\n    ...>   messages: messages,\n    ...> ])\n    {:ok, %{\"message\" => %{\n      \"role\" => \"assistant\",\n      \"content\" => \"Mie scattering affects all wavelengths similarly, while Rayleigh favors shorter ones.\"\n    }, ...}}\n\n    # Passing true to the :stream option initiates an async streaming request.\n    iex> Ollama.chat(client, [\n    ...>   model: \"llama2\",\n    ...>   messages: messages,\n    ...>   stream: true,\n    ...> ])\n    {:ok, Ollama.Streaming{}}","ref":"Ollama.html#chat/2-examples"},{"type":"function","title":"Ollama.check_blob/2","doc":"Checks a blob exists in ollama by its digest or binary data.","ref":"Ollama.html#check_blob/2"},{"type":"function","title":"Examples - Ollama.check_blob/2","doc":"iex> Ollama.check_blob(client, \"sha256:fe938a131f40e6f6d40083c9f0f430a515233eb2edaa6d72eb85c50d64f2300e\")\n    {:ok, true}\n\n    iex> Ollama.check_blob(client, \"this should not exist\")\n    {:ok, false}","ref":"Ollama.html#check_blob/2-examples"},{"type":"function","title":"Ollama.completion/2","doc":"Generates a completion for the given prompt using the specified model.\nOptionally streamable.","ref":"Ollama.html#completion/2"},{"type":"function","title":"Options - Ollama.completion/2","doc":"* `:model` (`t:String.t/0`) - Required. The ollama model name.\n* `:prompt` (`t:String.t/0`) - Required. Prompt to generate a response for.\n* `:images` (list of `t:String.t/0`) - A list of Base64 encoded images to be included with the prompt (for multimodal models only).\n* `:system` (`t:String.t/0`) - System prompt, overriding the model default.\n* `:template` (`t:String.t/0`) - Prompt template, overriding the model default.\n* `:context` - The context parameter returned from a previous `f:completion/2` call (enabling short conversational memory).\n* `:format` (`t:String.t/0`) - Set the expected format of the response (`json`).\n* `:raw` (`t:boolean/0`) - Set `true` if specifying a fully templated prompt. (`:template` is ingored)\n* `:stream` - See [section on streaming](#module-streaming). The default value is `false`.\n* `:keep_alive` - How long to keep the model loaded.\n* `:options` - Additional advanced [model parameters](https://github.com/jmorganca/ollama/blob/main/docs/modelfile.md#valid-parameters-and-values).","ref":"Ollama.html#completion/2-options"},{"type":"function","title":"Examples - Ollama.completion/2","doc":"iex> Ollama.completion(client, [\n    ...>   model: \"llama2\",\n    ...>   prompt: \"Why is the sky blue?\",\n    ...> ])\n    {:ok, %{\"response\": \"The sky is blue because it is the color of the sky.\", ...}}\n\n    # Passing true to the :stream option initiates an async streaming request.\n    iex> Ollama.completion(client, [\n    ...>   model: \"llama2\",\n    ...>   prompt: \"Why is the sky blue?\",\n    ...>   stream: true,\n    ...> ])\n    {:ok, %Ollama.Streaming{}}","ref":"Ollama.html#completion/2-examples"},{"type":"function","title":"Ollama.copy_model/2","doc":"Creates a model with another name from an existing model.","ref":"Ollama.html#copy_model/2"},{"type":"function","title":"Options - Ollama.copy_model/2","doc":"* `:source` (`t:String.t/0`) - Required. Name of the model to copy from.\n* `:destination` (`t:String.t/0`) - Required. Name of the model to copy to.","ref":"Ollama.html#copy_model/2-options"},{"type":"function","title":"Example - Ollama.copy_model/2","doc":"iex> Ollama.copy_model(client, [\n    ...>   source: \"llama2\",\n    ...>   destination: \"llama2-backup\"\n    ...> ])\n    {:ok, true}","ref":"Ollama.html#copy_model/2-example"},{"type":"function","title":"Ollama.create_blob/2","doc":"Creates a blob from its binary data.","ref":"Ollama.html#create_blob/2"},{"type":"function","title":"Example - Ollama.create_blob/2","doc":"iex> Ollama.create_blob(client, data)\n    {:ok, true}","ref":"Ollama.html#create_blob/2-example"},{"type":"function","title":"Ollama.create_model/2","doc":"Creates a model using the given name and model file. Optionally\nstreamable.\n\nAny dependent blobs reference in the modelfile, such as `FROM` and `ADAPTER`\ninstructions, must exist first. See `check_blob/2` and `create_blob/2`.","ref":"Ollama.html#create_model/2"},{"type":"function","title":"Options - Ollama.create_model/2","doc":"* `:name` (`t:String.t/0`) - Required. Name of the model to create.\n* `:modelfile` (`t:String.t/0`) - Required. Contents of the Modelfile.\n* `:stream` - See [section on streaming](#module-streaming). The default value is `false`.","ref":"Ollama.html#create_model/2-options"},{"type":"function","title":"Example - Ollama.create_model/2","doc":"iex> modelfile = \"FROM llama2\\nSYSTEM \\\"You are mario from Super Mario Bros.\\\"\"\n    iex> Ollama.create_model(client, [\n    ...>   name: \"mario\",\n    ...>   modelfile: modelfile,\n    ...>   stream: true,\n    ...> ])\n    {:ok, Ollama.Streaming{}}","ref":"Ollama.html#create_model/2-example"},{"type":"function","title":"Ollama.delete_model/2","doc":"Deletes a model and its data.","ref":"Ollama.html#delete_model/2"},{"type":"function","title":"Options - Ollama.delete_model/2","doc":"* `:source` (`t:String.t/0`) - Required. Name of the model to copy from.\n* `:destination` (`t:String.t/0`) - Required. Name of the model to copy to.","ref":"Ollama.html#delete_model/2-options"},{"type":"function","title":"Example - Ollama.delete_model/2","doc":"iex> Ollama.delete_model(client, name: \"llama2\")\n    {:ok, true}","ref":"Ollama.html#delete_model/2-example"},{"type":"function","title":"Ollama.embeddings/2","doc":"Generate embeddings from a model for the given prompt.","ref":"Ollama.html#embeddings/2"},{"type":"function","title":"Options - Ollama.embeddings/2","doc":"* `:model` (`t:String.t/0`) - Required. The name of the model used to generate the embeddings.\n* `:prompt` (`t:String.t/0`) - Required. The prompt used to generate the embedding.\n* `:keep_alive` - How long to keep the model loaded.\n* `:options` - Additional advanced [model parameters](https://github.com/jmorganca/ollama/blob/main/docs/modelfile.md#valid-parameters-and-values).","ref":"Ollama.html#embeddings/2-options"},{"type":"function","title":"Example - Ollama.embeddings/2","doc":"iex> Ollama.embeddings(client, [\n    ...>   model: \"llama2\",\n    ...>   prompt: \"Here is an article about llamas...\"\n    ...> ])\n    {:ok, %{\"embedding\" => [\n      0.5670403838157654, 0.009260174818336964, 0.23178744316101074, -0.2916173040866852, -0.8924556970596313,\n      0.8785552978515625, -0.34576427936553955, 0.5742510557174683, -0.04222835972905159, -0.137906014919281\n    ]}}","ref":"Ollama.html#embeddings/2-example"},{"type":"function","title":"Ollama.init/1","doc":"Creates a new Ollama API client. Accepts either a base URL for the Ollama API,\na keyword list of options passed to `Req.new/1`, or an existing `t:Req.Request.t/0`\nstruct.\n\nIf no arguments are given, the client is initiated with the default options:\n\n```elixir\n@default_req_opts [\n  base_url: \"http://localhost:11434/api\",\n  receive_timeout: 60_000,\n]\n```","ref":"Ollama.html#init/1"},{"type":"function","title":"Examples - Ollama.init/1","doc":"iex> client = Ollama.init(\"https://ollama.service.ai:11434/api\")\n    %Ollama{}","ref":"Ollama.html#init/1-examples"},{"type":"function","title":"Ollama.list_models/1","doc":"Lists all models that Ollama has available.","ref":"Ollama.html#list_models/1"},{"type":"function","title":"Example - Ollama.list_models/1","doc":"iex> Ollama.list_models(client)\n    {:ok, %{\"models\" => [\n      %{\"name\" => \"codellama:13b\", ...},\n      %{\"name\" => \"llama2:latest\", ...},\n    ]}}","ref":"Ollama.html#list_models/1-example"},{"type":"function","title":"Ollama.pull_model/2","doc":"Downloads a model from the ollama library. Optionally streamable.","ref":"Ollama.html#pull_model/2"},{"type":"function","title":"Options - Ollama.pull_model/2","doc":"* `:name` (`t:String.t/0`) - Required. Name of the model to pull.\n* `:stream` - See [section on streaming](#module-streaming). The default value is `false`.","ref":"Ollama.html#pull_model/2-options"},{"type":"function","title":"Example - Ollama.pull_model/2","doc":"iex> Ollama.pull_model(client, name: \"llama2\")\n    {:ok, %{\"status\" => \"success\"}}\n\n    # Passing true to the :stream option initiates an async streaming request.\n    iex> Ollama.pull_model(client, name: \"llama2\", stream: true)\n    {:ok, %Ollama.Streaming{}}","ref":"Ollama.html#pull_model/2-example"},{"type":"function","title":"Ollama.push_model/2","doc":"Upload a model to a model library. Requires registering for\n[ollama.ai](https://ollama.ai) and adding a public key first. Optionally streamable.","ref":"Ollama.html#push_model/2"},{"type":"function","title":"Options - Ollama.push_model/2","doc":"* `:name` (`t:String.t/0`) - Required. Name of the model to pull.\n* `:stream` - See [section on streaming](#module-streaming). The default value is `false`.","ref":"Ollama.html#push_model/2-options"},{"type":"function","title":"Example - Ollama.push_model/2","doc":"iex> Ollama.push_model(client, name: \"mattw/pygmalion:latest\")\n    {:ok, %{\"status\" => \"success\"}}\n\n    # Passing true to the :stream option initiates an async streaming request.\n    iex> Ollama.push_model(client, name: \"mattw/pygmalion:latest\", stream: true)\n    {:ok, %Ollama.Streaming{}}","ref":"Ollama.html#push_model/2-example"},{"type":"function","title":"Ollama.show_model/2","doc":"Shows all information for a specific model.","ref":"Ollama.html#show_model/2"},{"type":"function","title":"Options - Ollama.show_model/2","doc":"* `:name` (`t:String.t/0`) - Required. Name of the model to show.","ref":"Ollama.html#show_model/2-options"},{"type":"function","title":"Example - Ollama.show_model/2","doc":"iex> Ollama.show_model(client, name: \"llama2\")\n    {:ok, %{\n      \"details\" => %{\n        \"families\" => [\"llama\", \"clip\"],\n        \"family\" => \"llama\",\n        \"format\" => \"gguf\",\n        \"parameter_size\" => \"7B\",\n        \"quantization_level\" => \"Q4_0\"\n      },\n      \"modelfile\" => \"...\",\n      \"parameters\" => \"...\",\n      \"template\" => \"...\"\n    }}","ref":"Ollama.html#show_model/2-example"},{"type":"type","title":"Ollama.client/0","doc":"Client struct","ref":"Ollama.html#t:client/0"},{"type":"type","title":"Ollama.message/0","doc":"Chat message\n\nA chat message is a `t:map/0` with the following fields:\n\n* `:role` (`t:String.t/0`) - Required. The role of the message, either `system`, `user` or `assistant`.\n* `:content` (`t:String.t/0`) - Required. The content of the message.\n* `:images` (list of `t:String.t/0`) - *(optional)* List of Base64 encoded images (for multimodal models only).","ref":"Ollama.html#t:message/0"},{"type":"type","title":"Ollama.response/0","doc":"Client response","ref":"Ollama.html#t:response/0"},{"type":"module","title":"Ollama.API","doc":"> ##","ref":"Ollama.API.html"},{"type":"module","title":"API change {: .warning} - Ollama.API","doc":">\n> The `Ollama.API` module has been deprecated in favour of the top level\n`Ollama` module. Apologies for the namespace change. `Ollama.API` will be\nremoved in version 1.","ref":"Ollama.API.html#module-api-change-warning"},{"type":"function","title":"Ollama.API.chat/2","doc":"","ref":"Ollama.API.html#chat/2"},{"type":"function","title":"Ollama.API.check_blob/2","doc":"","ref":"Ollama.API.html#check_blob/2"},{"type":"function","title":"Ollama.API.completion/2","doc":"","ref":"Ollama.API.html#completion/2"},{"type":"function","title":"Ollama.API.copy_model/2","doc":"","ref":"Ollama.API.html#copy_model/2"},{"type":"function","title":"Ollama.API.create_blob/2","doc":"","ref":"Ollama.API.html#create_blob/2"},{"type":"function","title":"Ollama.API.create_model/2","doc":"","ref":"Ollama.API.html#create_model/2"},{"type":"function","title":"Ollama.API.delete_model/2","doc":"","ref":"Ollama.API.html#delete_model/2"},{"type":"function","title":"Ollama.API.embeddings/2","doc":"","ref":"Ollama.API.html#embeddings/2"},{"type":"function","title":"Ollama.API.list_models/1","doc":"","ref":"Ollama.API.html#list_models/1"},{"type":"function","title":"Ollama.API.new/1","doc":"","ref":"Ollama.API.html#new/1"},{"type":"function","title":"Ollama.API.pull_model/2","doc":"","ref":"Ollama.API.html#pull_model/2"},{"type":"function","title":"Ollama.API.push_model/2","doc":"","ref":"Ollama.API.html#push_model/2"},{"type":"function","title":"Ollama.API.show_model/2","doc":"","ref":"Ollama.API.html#show_model/2"},{"type":"module","title":"Ollama.Blob","doc":"Module for working for blobs in Ollama.\n\nCurrently this module only provides a function for generating a SHA256 digest\nof a binary blob.","ref":"Ollama.Blob.html"},{"type":"function","title":"Ollama.Blob.digest/1","doc":"Generates a SHA256 digest of a binary blob.","ref":"Ollama.Blob.html#digest/1"},{"type":"function","title":"Example - Ollama.Blob.digest/1","doc":"iex> Ollama.Blob.digest(\"hello\")\n    \"sha256:2cf24dba5fb0a30e26e83b2ac5b9e29e1b161e5c1fa7425e73043362938b9824\"","ref":"Ollama.Blob.html#digest/1-example"},{"type":"type","title":"Ollama.Blob.digest/0","doc":"Blob digest\n\nThe digest is a hex-encoded SHA256 hash of the binary blob, prefixed with the\nalgorithm.","ref":"Ollama.Blob.html#t:digest/0"},{"type":"type","title":"Example - Ollama.Blob.digest/0","doc":"\"sha256:054edec1d0211f624fed0cbca9d4f9400b0e491c43742af2c5b0abebf0c990d8\"","ref":"Ollama.Blob.html#t:digest/0-example"}],"content_type":"text/markdown"}